api.authentication.v1.radius package — Argus-Toolbelt 1.0 documentation

# api.authentication.v1.radius package

## Submodules

## api.authentication.v1.radius.radius_authenticate module

Autogenerated API

`api.authentication.v1.radius.radius_authenticate.` `authenticate`(userName: str = None, domain: str = None, mode: str = None, password: str = None, tokenCode: str = None, state: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Initiate a new user session using RADIUS authentication (PUBLIC) Requires RADIUS authentication to be enabled on the server, and for the user. Use /methods to check which authentication methods are available on the server.

  This is a 2-factor authentication method, which may require additional verification. The first request should have mode AUTHENTICATION, and carry username, password and tokencode. If the authentication is challenged, submit a new request with mode CHALLENGE, andinclude the state variable returned in the challenge.

  Return type: | `dict`

## Module contents